@@ -29,7 +29,7 @@
 #include <qlineedit.h>
 #include <qpushbutton.h>
 #include <qlabel.h>
-#include <qtextview.h>
+#include <qtextedit.h>
 #include <qspinbox.h>
 #include <qcombobox.h>
 #include <qstring.h>
@@ -55,9 +55,6 @@
 // Some constants
 static const int  MAX_ANSWER_LEN         = 100;
 static const int  MIN_LEFT_WIDTH         = 100;
-static const char CAPTION[]              = "kbe Test";
-static const char FOUND[]                = ":)";
-static const char NOT_FOUND[]            = ":(";
 static const int  ADDITIONAL_WIDTH       = 25;
 static const int  ADDITIONAL_HEIGHT      = 10;
 
@@ -89,16 +86,19 @@ static const char OPTION_SESSION[]                = "Test.Session";
 static const char OPTION_QUESTIONS[]              = "Test.Questions";
 static const char OPTION_LEVEL[]                  = "Test.Level";
 
-// Welcome & Help and other messages
-static const char END_OF_TEST[]  = "End of session. Start again or exit.";
-static const char WELCOME_TEXT[] = "To begin test press button 'New Test'.";
-static const char HELP_TEXT[]    =
+// Welcome, help and other messages
+static const char CAPTION[]      = QT_TR_NOOP("kbe Test");
+static const char FOUND[]        = QT_TR_NOOP(":)");
+static const char NOT_FOUND[]    = QT_TR_NOOP(":(");
+static const char END_OF_TEST[]  = QT_TR_NOOP("End of session. Start again or exit.");
+static const char WELCOME_TEXT[] = QT_TR_NOOP("To begin test press button 'New Test'.");
+static const char HELP_TEXT[]    = QT_TR_NOOP(
 	"Enter answer that you think is correct.<br>"
-	"Use <b>comma</b> (<b>,</b>) to separate two or more answers that you may have.<br>";
+	"Use <b>comma</b> (<b>,</b>) to separate two or more answers that you may have.<br>");
 
 // Status Info and word format message
-static const char STATUS_INFO[] = " Correct  %d%%  ( %d / %d )     Asked  %d%%  ( %d / %d )";
-static const char ASKED[]       = "%d.  %s";
+static const char STATUS_INFO[] = QT_TR_NOOP(" Correct  %1%  ( %2 / %3 )     Asked  %4%  ( %5 / %6 )");
+static const char ASKED[]       = QT_TR_NOOP("%1.  %2");
 
 // Color objects
 static const QColor COLOR_FOUND(0, 255, 0);
@@ -113,17 +113,17 @@ static const int LEVEL_CHARS[] = {300, 200, 100, 50, 0};
 //========================================================================
 Test::Test(QWidget *parent, const char *name, Translator *pDictionary, Registry *pReg, const QFont *pFont, const int pBorderWidth):QDialog(parent, name, true) {
 
-	setCaption(W2U(CAPTION));
+	setCaption(tr(CAPTION));
 	dictionary = pDictionary;
 	borderWidth = pBorderWidth;
 	reg = pReg;
 	font = QFont(*pFont);
-	buf = new char[MAX_ANSWER_LEN*2];
 
 	int X = 0, Y = 0, W = 0, H = 0;
 	sscanf(DEFAULT_GEOMETRY, "%d, %d, %d, %d", &X, &Y, &W, &H);
 	sscanf(reg->getString(OPTION_GEOMETRY, DEFAULT_GEOMETRY), "%d, %d, %d, %d", &X, &Y, &W, &H);
-	setGeometry(X, Y, W, H);
+	resize(QSize(W, H));
+	move(QPoint(X, Y));
 
 	translate = reg->getInt(OPTION_TRANSLATE, DEFAULT_TRANSLATE, MIN_TRANSLATE, MAX_TRANSLATE);
 	showAnswer = reg->getInt(OPTION_SHOW_ANSWER, DEFAULT_SHOW_ANSWER, MIN_SHOW_ANSWER, MAX_SHOW_ANSWER);
@@ -156,25 +156,29 @@ Test::Test(QWidget *parent, const char *name, Translator *pDictionary, Registry
 	word->setAlignment(QLabel::AlignLeft | QLabel::AlignVCenter);
 
 	// Create and set button new test
-	bnew = new QPushButton(W2U("&New Test"), this);
+	bnew = new QPushButton(tr("&New Test"), this);
 	CHECK_PTR(bnew);
 	connect(bnew, SIGNAL(clicked()), this, SLOT(button_New()));
 	bnew->setFocusPolicy(QPushButton::NoFocus);
+	bnew->setAutoDefault(false);
 
 	// Create and set button close
-	bclose = new QPushButton(W2U("&Close"), this);
+	bclose = new QPushButton(tr("&Close"), this);
 	CHECK_PTR(bclose);
 	connect(bclose, SIGNAL(clicked()), this, SLOT(reject()));
 	bclose->setFocusPolicy(QPushButton::NoFocus);
+	bclose->setAutoDefault(false);
 
 	// Create and set button help
-	bhelp = new QPushButton(W2U("&Help"), this);
+	bhelp = new QPushButton(tr("&Help"), this);
 	CHECK_PTR(bhelp);
 	connect(bhelp, SIGNAL(clicked()), this, SLOT(button_Help()));
 	bhelp->setFocusPolicy(QPushButton::NoFocus);
+	bhelp->setAutoDefault(false);
 
 	// Create and set result to show
-	result = new QTextView(this);
+	result = new QTextEdit(this);
+	result->setReadOnly(true);
 	CHECK_PTR(result);
 
 	// Create and set label info
@@ -188,8 +192,7 @@ Test::Test(QWidget *parent, const char *name, Translator *pDictionary, Registry
 
 	// Set focus
 	answer->setFocus();
-	question->setText(W2U(WELCOME_TEXT));
-
+	question->setText(tr(WELCOME_TEXT));
 } // End of Constructor
 
 
@@ -205,7 +208,7 @@ Test::~Test() {
 	reg->setInt(OPTION_LEVEL, level);
 	if (!isMinimized()) {
 		char val[32];
-		sprintf(val, "%d, %d, %d, %d", x(), y(), width(), height());
+		sprintf(val, "%d, %d, %d, %d", pos().x(), pos().y(), size().width(), size().height());
 		reg->setString(OPTION_GEOMETRY, val);
 	}
 	delete answer;
@@ -217,7 +220,6 @@ Test::~Test() {
 	delete word;
 	delete info;
 	delete result;
-	delete [] buf;
 } // End of Destructor
 
 
@@ -232,7 +234,7 @@ void Test::answer_EnterPressed() {
 		return;
 	}
 	// Clear fields
-	result->setText(W2U(""));
+	result->clear();
 	// Check for new sessoin
 	if (current == 0) {
 		// Start new session
@@ -252,37 +254,45 @@ void Test::answer_EnterPressed() {
 		// Check result
 		if (dictionary->testWord(U2W(answer->text()))) {
 			correct++;
-			strcpy(buf, FOUND);
 			found->setBackgroundColor(COLOR_FOUND);
-			found->setText(W2U(FOUND));
+			found->setText(tr(FOUND));
 		}
 		else {
-			strcpy(buf, NOT_FOUND);
 			found->setBackgroundColor(COLOR_NOT_FOUND);
-			found->setText(W2U(NOT_FOUND));
+			found->setText(tr(NOT_FOUND));
 			if (((showAnswer == 2) && ((answer->text()).length() > 0)) || ((showAnswer == 3) && ((answer->text()).length() == 0)) || (showAnswer == 4)) {
 				result->setText(W2U(dictionary->getResult()));
+				result->sync();
+				result->setCursorPosition(0, 0);
 			}
 		}
 		word->setText(answer->text());
 		answer->clear();
 		if (showAnswer == 1) {
 			result->setText(W2U(dictionary->getResult()));
+			result->sync();
+			result->setCursorPosition(0, 0);
 		}
 	}
 	// Show status
-	sprintf(buf, STATUS_INFO, (current == 0 ? 0 : (correct*100)/current), correct, current, ( questions == 0 ? 0 : (current*100)/questions), current, questions);
-	info->setText(W2U(buf));
+	info->setText(tr(STATUS_INFO)
+			.arg((current == 0 ? 0 : (correct*100)/current))
+			.arg(correct)
+			.arg(current)
+			.arg((questions == 0 ? 0 : (current*100)/questions))
+			.arg(current)
+			.arg(questions));
 	// Increase current ponter
 	current++;
 	// Generata next random word or end of test
 	if (current > questions) {
-		strcpy(buf, END_OF_TEST);
+		question->setText(tr(END_OF_TEST));
 	}
 	else {
-		sprintf(buf, ASKED, current, dictionary->getNextRandomWord());
+		question->setText(tr(ASKED)
+				.arg(current)
+				.arg(W2U(dictionary->getNextRandomWord())));
 	}
-	question->setText(W2U(buf));
 } // End of answer_EnterPressed
 
 
@@ -293,7 +303,7 @@ void Test::answer_EnterPressed() {
 void Test::button_New() {
 
 	QDialog options(this, "new", true);
-	options.setCaption(W2U("New Test"));
+	options.setCaption(tr("New Test"));
 
 	QFontMetrics fm = options.fontMetrics();
 	int h = fm.height();    // Height of element
@@ -303,44 +313,39 @@ void Test::button_New() {
 	int s = h;              // Additional space between groups
 	int m = 0;              // Max width of element (Used for alignment)
 
-	QLabel ltf(W2U("Translate:"), &options);
+	QLabel ltf(tr("Translate:"), &options);
 	ltf.setAlignment(QLabel::AlignRight | QLabel::AlignVCenter);
 	ltf.adjustSize();
 	ltf.move(x, y);
 
 	QComboBox tf(false, &options);
-	tf.insertItem(W2U("From English To Bulgarian"));
-	tf.insertItem(W2U("From Bulgarian To English"));
+	tf.insertItem(tr("From English To Bulgarian"));
+	tf.insertItem(tr("From Bulgarian To English"));
 	tf.setCurrentItem(translate - 1);
 	tf.adjustSize();
 	tf.move(x + ltf.width() + w, y);
 
-	QLabel lsa(W2U("Show answer:"), &options);
+	QLabel lsa(tr("Show answer:"), &options);
 	lsa.setAlignment(QLabel::AlignRight | QLabel::AlignVCenter);
 	lsa.adjustSize();
 	lsa.move(x, tf.y() + tf.height() + y);
 
 	QComboBox sa(false, &options);
-	sa.insertItem(W2U("Every time"));
-	sa.insertItem(W2U("In wrong answer"));
-	sa.insertItem(W2U("In empty answer"));
-	sa.insertItem(W2U("In wrong or empty answer"));
-	sa.insertItem(W2U("Never"));
+	sa.insertItem(tr("Every time"));
+	sa.insertItem(tr("In wrong answer"));
+	sa.insertItem(tr("In empty answer"));
+	sa.insertItem(tr("In wrong or empty answer"));
+	sa.insertItem(tr("Never"));
 	sa.setCurrentItem(showAnswer - 1);
 	sa.adjustSize();
 	sa.move(x + lsa.width() + w, lsa.y());
 
-	// Right Justify last elements
+	// Make the two elements with the same size
 	m = (tf.width() > sa.width() ? tf.width() : sa.width());
 	tf.resize(m, tf.height());
 	sa.resize(m, sa.height());
-	m = (ltf.width() > lsa.width() ? ltf.width() : lsa.width());
-	ltf.resize(m, tf.height());
-	lsa.resize(m, sa.height());
-	tf.move(x + m + w, tf.y());
-	sa.move(x + m + w, sa.y());
 
-	QLabel lsn(W2U("Session (0 - random):"), &options);
+	QLabel lsn(tr("Session (0 - random):"), &options);
 	lsn.setAlignment(QLabel::AlignRight | QLabel::AlignVCenter);
 	lsn.adjustSize();
 	lsn.move(x, sa.y() + sa.height() + y + s);
@@ -350,7 +355,7 @@ void Test::button_New() {
 	sn.adjustSize();
 	sn.move(x + lsn.width() + w, lsn.y());
 
-	QLabel lqn(W2U("Number of questions:"), &options);
+	QLabel lqn(tr("Number of questions:"), &options);
 	lqn.setAlignment(QLabel::AlignRight | QLabel::AlignVCenter);
 	lqn.adjustSize();
 	lqn.move(x, sn.y() + sn.height() + y);
@@ -360,43 +365,56 @@ void Test::button_New() {
 	qn.adjustSize();
 	qn.move(x + lqn.width() + w, lqn.y());
 
-	// Right Justify last elements
+	// Make the two elements with the same size
 	m = (sn.width() > qn.width() ? sn.width() : qn.width());
 	sn.resize(m, sn.height());
 	qn.resize(m, qn.height());
-	m = (lsn.width() > lqn.width() ? lsn.width() : lqn.width());
+
+	QLabel llv(tr("Test difficult level:"), &options);
+	llv.setAlignment(QLabel::AlignRight | QLabel::AlignVCenter);
+	llv.adjustSize();
+	llv.move(x, qn.y() + qn.height() + y + s);
+
+	QComboBox lv(false, &options);
+	lv.insertItem(tr("Novice"));
+	lv.insertItem(tr("Beginner"));
+	lv.insertItem(tr("Intermediate"));
+	lv.insertItem(tr("Specialist"));
+	lv.insertItem(tr("Expert"));
+	lv.setCurrentItem(level - 1);
+	lv.adjustSize();
+	lv.move(x + llv.width() + w, llv.y());
+
+	// Determine max size of labels
+	m = 0;
+	m = (ltf.width() > m ? ltf.width() : m);
+	m = (lsa.width() > m ? lsa.width() : m);
+	m = (lsn.width() > m ? lsn.width() : m);
+	m = (lqn.width() > m ? lqn.width() : m);
+	m = (llv.width() > m ? llv.width() : m);
+	// Set labels with max size
+	ltf.resize(m, tf.height());
+	lsa.resize(m, sa.height());
 	lsn.resize(m, sn.height());
 	lqn.resize(m, qn.height());
+	llv.resize(m, lv.height());
+	// Move other elements relative to labels
+	tf.move(x + m + w, tf.y());
+	sa.move(x + m + w, sa.y());
 	sn.move(x + m + w, sn.y());
 	qn.move(x + m + w, qn.y());
+	lv.move(x + m + w, lv.y());
 
-	QLabel llvl(W2U("Test difficult level:"), &options);
-	llvl.setAlignment(QLabel::AlignRight | QLabel::AlignVCenter);
-	llvl.adjustSize();
-	llvl.move(x, qn.y() + qn.height() + y + s);
-
-	QComboBox lvl(false, &options);
-	lvl.insertItem(W2U("Novice"));
-	lvl.insertItem(W2U("Beginner"));
-	lvl.insertItem(W2U("Intermediate"));
-	lvl.insertItem(W2U("Specialist"));
-	lvl.insertItem(W2U("Expert"));
-	lvl.setCurrentItem(level - 1);
-	lvl.adjustSize();
-	lvl.move(x + llvl.width() + w, llvl.y());
-
-	// Right Justify last elements
-	llvl.resize(llvl.width(), lvl.height());
-
-	QPushButton ok(W2U("OK"), &options);
+	// Create buttons
+	QPushButton ok(tr("&OK"), &options);
 	ok.setDefault(true);
 	connect(&ok, SIGNAL(clicked()), &options, SLOT(accept()));
 
-	QPushButton cancel(W2U("Cancel"), &options);
+	QPushButton cancel(tr("&Cancel"), &options);
 	connect(&cancel, SIGNAL(clicked()), &options, SLOT(reject()));
 	cancel.adjustSize();
 
-	cancel.move(tf.x() + tf.width() - cancel.width(), lvl.y() + lvl.height() + (s + y)*2);
+	cancel.move(tf.x() + tf.width() - cancel.width(), lv.y() + lv.height() + (s + y)*2);
 	ok.setGeometry(cancel.x() - cancel.width() - x, cancel.y(), cancel.width(), cancel.height());
 
 	options.setFixedSize(cancel.x() + cancel.width() + x, cancel.y() + cancel.height() + y);
@@ -405,11 +423,12 @@ void Test::button_New() {
 	if (options.exec() == QDialog::Accepted) {
 		translate = tf.currentItem() + 1;
 		showAnswer = sa.currentItem() + 1;
-		level = lvl.currentItem() + 1;
+		level = lv.currentItem() + 1;
 		session = sn.value();
 		questions = qn.value();
 		current = 0;
 		correct = 0;
+		answer->setFocus();
 		answer_EnterPressed();
 	}
 
@@ -421,7 +440,9 @@ void Test::button_New() {
 // Shows help message in result text view
 //========================================================================
 void Test::button_Help() {
-	result->setText(W2U(HELP_TEXT));
+	result->setText(tr(HELP_TEXT));
+	result->sync();
+	result->setCursorPosition(0, 0);
 } // End of button_Help
 
 
