@@ -15,7 +15,7 @@
 class QLineEdit;
 class QPushButton;
 class QLabel;
-class QTextView;
+class QTextEdit;
 class QCheckBox;
 class QSpinBox;
 class QComboBox;
@@ -49,7 +49,7 @@ private:
 	QLabel *found;
 	QLabel *word;
 	QLabel *info;
-	QTextView *result;
+	QTextEdit *result;
 
 	Translator *dictionary;
 	Registry *reg;
@@ -64,8 +64,6 @@ private:
 	int current;
 	int correct;
 
-	char *buf;
-
 }; // End of class Test
 
 #endif
