@@ -33,7 +33,7 @@
 #include <qpushbutton.h>
 #include <qlabel.h>
 #include <qlistbox.h>
-#include <qtextview.h>
+#include <qtextedit.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
 #include <qcombobox.h>
@@ -41,16 +41,14 @@
 #include <qimage.h>
 #include <qstring.h>
 #include <qmotifstyle.h>
-#include <qcdestyle.h>
+#include <qmotifplusstyle.h>
 #include <qwindowsstyle.h>
 #include <qplatinumstyle.h>
 
 #ifdef WITH_KDE
 #include <kapp.h>
 #include <kmenubar.h>
-//#include <kfontdialog.h>
-// To the moment KFontDialog doesn't provide way to select CharSet
-#include <qfontdialog.h>
+#include <kfontdialog.h>
 #else
 #include <qapplication.h>
 #include <qfontdialog.h>
@@ -68,8 +66,8 @@
 #include "test.h"
 
 // Include Icon and Image of dic
-#include "kbedicicon.xpm"
-#include "kbediciconmini.xpm"
+#include "kbedic_icon.xpm"
+#include "kbedic_icon_mini.xpm"
 
 // Include config.h autoconfiguration generated file
 #include "config.h"
@@ -88,51 +86,45 @@
 // Some Constants
 static const int  MAX_WORD_LEN           = 70;
 static const int  MAX_WORDS_ALLOWED      = 7;
-#ifdef ENG_BUL_DAT_CONFIG
-static const char ENG_BUL_DAT[]          = ENG_BUL_DAT_CONFIG;
+#ifdef DATA_DIR_CONFIG
+static const char DATA_DIR[]             = DATA_DIR_CONFIG;
 #else
-static const char ENG_BUL_DAT[]          = "/usr/local/share/engbul.dat";
-#endif
-#ifdef BUL_ENG_DAT_CONFIG
-static const char BUL_ENG_DAT[]          = BUL_ENG_DAT_CONFIG;
-#else
-static const char BUL_ENG_DAT[]          = "/usr/local/share/buleng.dat";
+static const char DATA_DIR[]             = "/usr/local/share/kbedic/";
 #endif
 static const char REGISTRY_FILE[]        = ".kbedic";
 static const char REGISTRY_FILE_SUFFIX[] = "~";
 static const char ENV_HOME[]             = "HOME";
-static const char CAPTION[]              = "kbe Dictionary";
-static const char FOUND[]                = "Found";
-static const char NOT_FOUND[]            = "";
-static const char ADV_SRCH_LABEL[]       = "%d words   ";
 static const int  ADDITIONAL_WIDTH       = 25;
 static const int  ADDITIONAL_HEIGHT      = 10;
-
+static const char CAPTION[]              = QT_TR_NOOP("kbe Dictionary");
+static const char FOUND[]                = QT_TR_NOOP("Found");
+static const char NOT_FOUND[]            = QT_TR_NOOP("\x20"); // Space. Can be tr in bg.
+static const char ADV_SRCH_LABEL[]       = QT_TR_NOOP("%1 words   ");
 
 // Messages
-static const char HELP_MESSAGE[] =
-	"To perform <b>Advanced Search</b> click button <b>'?'</b>. "
-	"It is a very powerful function that searchs entered word(s) in data.<br><br>"
-	"<b>Advanced Search</b> accepts as control chars '<b>+</b>', '<b>-</b>' and '<b>\"</b>'.<br>"
-	"<b>+go +in</b> means <b>go</b> AND <b>in</b><br>"
-	"<b>\"go in\"</b> means exact phrase <b>go in</b><br>"
-	"<b>+go +in -out</b> means <b>go</b> AND <b>in</b> AND NO <b>out</b><br><br>"
-	"You can omit control chars. In this case options <b>Search for exact phrase</b> "
-	" in <b>Main Menu/Tools/Advanced Search</b> is important.<br>"
-	"<b>go in</b> means <b>\"go in\"</b> when option is checked.<br>"
-	"<b>go in</b> means <b>+go +in</b> when option is unchecked.<br>"
-	"But be careful when you make complicated queries because.<br>"
-	"<b>go in +go out</b> means <b>+\"go in\" +\"go out\"</b> in first case.<br>"
-	"<b>go in +go out</b> means <b>+go +in +go +out</b> in second case.<br><br>"
-	"Another important options is <b>Search for whole word(s)</b> in "
-	"<b>Main Menu/Tools/Advanced Search</b>.<br>"
-	"<b>go</b> means whole/exact word <b>go</b> when option is checked.<br>"
-	"<b>go</b> means also <b>go</b>al, car<b>go</b> ... when option is unchecked.<br><br>"
-	"For more information and help please look at <b>README</b> and <b>FAQ</b> files "
-	"that come with the distribution package.<br>";
+static const char HELP_MESSAGE[] = QT_TR_NOOP(
+	"To perform <b>Advanced Search</b> click button <b>'?'</b>.\n"
+	" It is a very powerful function that searchs entered word(s) in data.<br><br>\n"
+	"<b>Advanced Search</b> accepts as control chars '<b>+</b>', '<b>-</b>' and '<b>\"</b>'.<br>\n"
+	"<b>+go +in</b> means <b>go</b> AND <b>in</b><br>\n"
+	"<b>\"go in\"</b> means exact phrase <b>go in</b><br>\n"
+	"<b>+go +in -out</b> means <b>go</b> AND <b>in</b> AND NO <b>out</b><br><br>\n"
+	"You can omit control chars. In this case options <b>Search for exact phrase</b>\n"
+	" in <b>Main Menu/Tools/Advanced Search</b> is important.<br>\n"
+	"<b>go in</b> means <b>\"go in\"</b> when option is checked.<br>\n"
+	"<b>go in</b> means <b>+go +in</b> when option is unchecked.<br>\n"
+	"But be careful when you make complicated queries because.<br>\n"
+	"<b>go in +go out</b> means <b>+\"go in\" +\"go out\"</b> in first case.<br>\n"
+	"<b>go in +go out</b> means <b>+go +in +go +out</b> in second case.<br><br>\n"
+	"Another important options is <b>Search for whole word(s)</b> in\n"
+	" <b>Main Menu/Tools/Advanced Search</b>.<br>\n"
+	"<b>go</b> means whole/exact word <b>go</b> when option is checked.<br>\n"
+	"<b>go</b> means also <b>go</b>al, car<b>go</b> ... when option is unchecked.<br><br>\n"
+	"For more information and help please look at <b>README</b> and <b>FAQ</b> files\n"
+	" that come with the distribution package.<br>");
 
-static const char ABOUT_MESSAGE[] =
-	"kbe Dictionary version 2.1\n"
+static const char ABOUT_MESSAGE[] = QT_TR_NOOP(
+	"kbe Dictionary version %1\n"
 	"Copyright (C) 2000 Radostin Radnev\n"
 	"\n"
 	"Home page: http://kbedic.sourceforge.net\n"
@@ -141,7 +133,7 @@ static const char ABOUT_MESSAGE[] =
 	"NO WARRANTY. This is free software, and\n"
 	"you are welcome to redistribute it under\n"
 	"certain conditions. For details read file\n"
-	"COPYING that comes with this package.";
+	"COPYING that comes with this package.");
 
 
 // Default options
@@ -159,7 +151,6 @@ static const char DEFAULT_FONT_NAME[]              = "*";
 static const int  DEFAULT_FONT_SIZE                = 14;
 static const int  DEFAULT_FONT_WEIGHT              = 50;
 static const bool DEFAULT_FONT_ITALIC              = false;
-static const int  DEFAULT_FONT_CHARSET             = QFont::Latin1;
 static const char DEFAULT_GEOMETRY[]               = "50, 50, 500, 300";
 static const bool DEFAULT_ADV_SRCH_HIGHLIGHT       = true;
 static const bool DEFAULT_ADV_SRCH_WHOLE_WORD      = true;
@@ -186,8 +177,7 @@ static const int  MIN_SYSTEM_STYLE      = 1;
 
 
 // Strings in registry
-static const char OPTION_ENG_BUL_DAT[]              = "EngBulDat";
-static const char OPTION_BUL_ENG_DAT[]              = "BulEngDat";
+static const char OPTION_DATA_DIR[]                 = "DataDir";
 static const char OPTION_INPUT_FIELD_WIDTH[]        = "InputFieldWidth";
 static const char OPTION_LEFT_PANE_WIDTH[]          = "LeftPaneWidth";
 static const char OPTION_WORDS_IN_LIST[]            = "WordsInList";
@@ -202,7 +192,6 @@ static const char OPTION_FONT_NAME[]                = "FontName";
 static const char OPTION_FONT_SIZE[]                = "FontSize";
 static const char OPTION_FONT_WEIGHT[]              = "FontWeight";
 static const char OPTION_FONT_ITALIC[]              = "FontItalic";
-static const char OPTION_FONT_CHARSET[]             = "FontCharset";
 static const char OPTION_GEOMETRY[]                 = "Geometry";
 static const char OPTION_ADV_SRCH_HIGHLIGHT[]       = "AdvSrch.Highlight";
 static const char OPTION_ADV_SRCH_WHOLE_WORD[]      = "AdvSrch.WholeWord";
@@ -218,7 +207,7 @@ static const char OPTION_ADV_SRCH_ASD_DO_NOT_REPL[] = "AdvSrch.DoNotReplacePhras
 // Create GUI
 // Init objects and set default variables
 //========================================================================
-Win::Win(QWidget *parent = 0, const char *name = 0):QMainWindow(parent, name) {
+Win::Win(QWidget *parent, const char *name):QMainWindow(parent, name) {
 
 	// Init some variables
 	fromSystemHighlighted = false;
@@ -238,8 +227,8 @@ Win::Win(QWidget *parent = 0, const char *name = 0):QMainWindow(parent, name) {
 
 	// Get English Bulgarian Dictionary
 	dataOk = true;
-	dataOk = ((dataOk) && (dictionary->createDictionary(reg->getString(OPTION_ENG_BUL_DAT, ENG_BUL_DAT), dictionary->ENG_BUL)));
-	dataOk = ((dataOk) && (dictionary->createDictionary(reg->getString(OPTION_BUL_ENG_DAT, BUL_ENG_DAT), dictionary->BUL_ENG)));
+	dataOk = ((dataOk) && (dictionary->createDictionary(reg->getString(OPTION_DATA_DIR, DATA_DIR), dictionary->ENG_BUL)));
+	dataOk = ((dataOk) && (dictionary->createDictionary(reg->getString(OPTION_DATA_DIR, DATA_DIR), dictionary->BUL_ENG)));
 
 	// Read data from ini file and set it
 	inputFieldWidth = reg->getInt(OPTION_INPUT_FIELD_WIDTH, DEFAULT_INPUT_FIELD_WIDTH, MIN_INPUT_FIELD_WIDTH, MAX_INPUT_FIELD_WIDTH);
@@ -270,52 +259,52 @@ Win::Win(QWidget *parent = 0, const char *name = 0):QMainWindow(parent, name) {
 		W2U(reg->getString(OPTION_FONT_NAME, DEFAULT_FONT_NAME)),
 		reg->getInt(OPTION_FONT_SIZE, DEFAULT_FONT_SIZE),
 		reg->getInt(OPTION_FONT_WEIGHT, DEFAULT_FONT_WEIGHT),
-		reg->getBool(OPTION_FONT_ITALIC, DEFAULT_FONT_ITALIC),
-		(QFont::CharSet)reg->getInt(OPTION_FONT_CHARSET, DEFAULT_FONT_CHARSET));
+		reg->getBool(OPTION_FONT_ITALIC, DEFAULT_FONT_ITALIC));
 
 	// Set caption of window
-	setCaption(W2U(CAPTION));
+	setCaption(tr(CAPTION));
 	// Set icon of window
-	QPixmap p1(diciconmini);
+	QPixmap p1(kbedic_icon_mini);
 	setIcon(p1);
 
 	// Set positions and size of window
 	int X = 0, Y = 0, W = 0, H = 0;
 	sscanf(DEFAULT_GEOMETRY, "%d, %d, %d, %d", &X, &Y, &W, &H);
 	sscanf(reg->getString(OPTION_GEOMETRY, DEFAULT_GEOMETRY), "%d, %d, %d, %d", &X, &Y, &W, &H);
-	setGeometry(X, Y, W, H);
+	resize(QSize(W, H));
+	move(QPoint(X, Y));
 
 	// Create and set menu
 	QPopupMenu *file = new QPopupMenu(this);
 	CHECK_PTR(file);
-	file->insertItem(W2U("E&xit"), qApp, SLOT(quit()), CTRL + Key_Q);
+	file->insertItem(tr("E&xit"), qApp, SLOT(quit()), CTRL + Key_Q);
 
 	QPopupMenu *edit = new QPopupMenu(this);
 	CHECK_PTR(edit);
-	edit->insertItem(W2U("&Copy"), this, SLOT(menu_Copy()), CTRL + Key_C);
-	edit->insertItem(W2U("&Paste"), this, SLOT(menu_Paste()), CTRL + Key_V);
+	edit->insertItem(tr("&Copy"), this, SLOT(menu_Copy()), CTRL + Key_C);
+	edit->insertItem(tr("&Paste"), this, SLOT(menu_Paste()), CTRL + Key_V);
 	edit->insertSeparator();
-	edit->insertItem(W2U("&Select All"), this, SLOT(menu_SelectAll()), CTRL + Key_A);
-	edit->insertItem(W2U("C&lear"), this, SLOT(menu_Clear()), CTRL + Key_D);
+	edit->insertItem(tr("&Select All"), this, SLOT(menu_SelectAll()), CTRL + Key_A);
+	edit->insertItem(tr("C&lear"), this, SLOT(menu_Clear()), CTRL + Key_D);
 	edit->insertSeparator();
-	edit->insertItem(W2U("&Advanced Search"), this, SLOT(button_Search()), CTRL + Key_S);
+	edit->insertItem(tr("&Advanced Search"), this, SLOT(button_Search()), CTRL + Key_S);
 	edit->insertSeparator();
-	edit->insertItem(W2U("History &Back"), this, SLOT(button_Prev()), CTRL + Key_Left);
-	edit->insertItem(W2U("History &Forward"), this, SLOT(button_Next()), CTRL + Key_Right);
+	edit->insertItem(tr("History &Back"), this, SLOT(button_Prev()), CTRL + Key_Left);
+	edit->insertItem(tr("History &Forward"), this, SLOT(button_Next()), CTRL + Key_Right);
 
 	QPopupMenu *options = new QPopupMenu(this);
 	CHECK_PTR(options);
-	options->insertItem(W2U("&Font..."), this, SLOT(menu_Font()));
-	options->insertItem(W2U("&Options..."), this, SLOT(menu_Options()));
-	options->insertItem(W2U("&Advanced Search..."), this, SLOT(menu_AdvancedSearch()));
+	options->insertItem(tr("&Font..."), this, SLOT(menu_Font()));
+	options->insertItem(tr("&Options..."), this, SLOT(menu_Options()));
+	options->insertItem(tr("&Advanced Search..."), this, SLOT(menu_AdvancedSearch()));
 	options->insertSeparator();
-	options->insertItem(W2U("&Test..."), this, SLOT(menu_Test()));
+	options->insertItem(tr("&Test..."), this, SLOT(menu_Test()));
 
 	QPopupMenu *help = new QPopupMenu(this);
 	CHECK_PTR(help);
-	help->insertItem(W2U("&Help"), this, SLOT(menu_Help()), Key_F1);
+	help->insertItem(tr("&Help"), this, SLOT(menu_Help()), Key_F1);
 	help->insertSeparator();
-	help->insertItem(W2U("&About..."), this, SLOT(menu_About()));
+	help->insertItem(tr("&About..."), this, SLOT(menu_About()));
 
 #ifdef WITH_KDE
 	KMenuBar *menu = new KMenuBar(this);
@@ -323,10 +312,10 @@ Win::Win(QWidget *parent = 0, const char *name = 0):QMainWindow(parent, name) {
 	QMenuBar *menu = new QMenuBar(this);
 #endif
 
-	menu->insertItem(W2U("&File"), file);
-	menu->insertItem(W2U("&Edit"), edit);
-	menu->insertItem(W2U("&Tools"), options);
-	menu->insertItem(W2U("&Help"), help);
+	menu->insertItem(tr("&File"), file);
+	menu->insertItem(tr("&Edit"), edit);
+	menu->insertItem(tr("&Tools"), options);
+	menu->insertItem(tr("&Help"), help);
 
 	// Create and set Word (text field)
 	word = new QLineEdit(W2U(""), this);
@@ -336,20 +325,20 @@ Win::Win(QWidget *parent = 0, const char *name = 0):QMainWindow(parent, name) {
 	connect(word, SIGNAL(textChanged(const QString&)), this, SLOT(word_TextChanged(const QString&)));
 
 	// Create and set button advanced search
-	bsearch = new QPushButton(W2U("?"), this);
+	bsearch = new QPushButton(tr("?"), this);
 	CHECK_PTR(bsearch);
 	bsearch->setFocusPolicy(NoFocus);
 	connect(bsearch, SIGNAL(clicked()), this, SLOT(button_Search()));
 
 	// Create and set button previous
-	bprev = new QPushButton(W2U("<"), this);
+	bprev = new QPushButton(tr("<"), this);
 	CHECK_PTR(bprev);
 	bprev->setFocusPolicy(NoFocus);
 	bprev->setEnabled(false);
 	connect(bprev, SIGNAL(clicked()), this, SLOT(button_Prev()));
 
 	// Create and set button next
-	bnext = new QPushButton(W2U(">"), this);
+	bnext = new QPushButton(tr(">"), this);
 	CHECK_PTR(bnext);
 	bnext->setFocusPolicy(NoFocus);
 	bnext->setEnabled(false);
@@ -363,7 +352,7 @@ Win::Win(QWidget *parent = 0, const char *name = 0):QMainWindow(parent, name) {
 	// Create and set picture
 	pic = new QLabel(this);
 	CHECK_PTR(pic);
-	QPixmap p2(dicicon);
+	QPixmap p2(kbedic_icon);
 	pic->setPixmap(p2);
 	pic->setFixedSize(p2.width(), p2.height());
 
@@ -375,7 +364,8 @@ Win::Win(QWidget *parent = 0, const char *name = 0):QMainWindow(parent, name) {
 	connect(list, SIGNAL(selected(const QString&)), this, SLOT(list_Selected(const QString&)));
 
 	// Create and set translation result
-	result = new QTextView(this);
+	result = new QTextEdit(this);
+	result->setReadOnly(true);
 	CHECK_PTR(result);
 
 	// Get application clipboard
@@ -403,7 +393,7 @@ Win::~Win() {
 	if (dataOk) {
 		if ((dataOk) && (!isMinimized())) {
 			char val[32];
-			sprintf(val, "%d, %d, %d, %d", x(), y(), width(), height());
+			sprintf(val, "%d, %d, %d, %d", pos().x(), pos().y(), size().width(), size().height());
 			reg->setString(OPTION_GEOMETRY, val);
 		}
 		delete dictionary;
@@ -432,6 +422,16 @@ bool Win::getDataOk() {
 
 
 
+//=== Get Locale File ====================================================
+// Return path and prefix of locale files
+//========================================================================
+char *Win::getLocalePath() {
+	Registry *r = new Registry(getenv(ENV_HOME), REGISTRY_FILE, REGISTRY_FILE_SUFFIX);
+	return r->getString(OPTION_DATA_DIR, DATA_DIR);
+} // End of getLocaleFile
+
+
+
 //=== Button Prev ========================================================
 // Invoked from click at previous button
 //========================================================================
@@ -523,14 +523,16 @@ void Win::word_EnterPressed() {
 		dictionary->advancedSearchState = false;
 	}
 	if (dictionary->findWord(U2W(word->text()), &Translation)) {
-		found->setText(W2U(FOUND));
+		found->setText(tr(FOUND));
 	}
 	else {
-		found->setText(W2U(NOT_FOUND));
+		found->setText(tr(NOT_FOUND));
 	}
 	if (Translation[0] != '\0') {
 		if ((strcmp(Translation, U2W(result->text())) != 0) || (fromListSelected) || (fromSystem)) {
 			result->setText(W2U(Translation));
+			result->sync();
+			result->setCursorPosition(0, 0);
 			if (list->isEnabled()) {
 				int i = 0;
 				list->clear();
@@ -588,11 +590,9 @@ void Win::button_Search() {
 			list->setCurrentItem(0);
 		}
 		else {
-			result->setText(W2U(""));
+			result->clear();
 		}
-		char b[strlen(ADV_SRCH_LABEL) + 5];
-		sprintf(b, ADV_SRCH_LABEL, i);
-		found->setText(W2U(b));
+		found->setText(tr(ADV_SRCH_LABEL).arg(i));
 	}
 } // End of button_Search
 
@@ -626,6 +626,8 @@ void Win::list_Highlighted(const QString &newText) {
 	else {
 		dictionary->findWord(U2W(newText), &Translation);
 		result->setText(W2U(Translation));
+		result->sync();
+		result->setCursorPosition(0, 0);
 		if (fromAdvancedSearch) {
 			fromAdvancedSearch = false;
 		}
@@ -710,7 +712,7 @@ void Win::menu_SelectAll() {
 void Win::menu_Options() {
 
 	QDialog options(this, "options", true);
-	options.setCaption(W2U("Options"));
+	options.setCaption(tr("Options"));
 
 	QFontMetrics fm = options.fontMetrics();
 	int h = fm.height();    // Height of element
@@ -721,27 +723,27 @@ void Win::menu_Options() {
 	int m = 0;              // Max width of element (Used for alignment)
 
 
-	QCheckBox toek(W2U("Translate on every keystroke"), &options);
+	QCheckBox toek(tr("Translate on every keystroke"), &options);
 	toek.setChecked(translateOnEveryKey);
 	toek.adjustSize();
 	toek.move(x, y);
 
-	QCheckBox sm(W2U("Separate different meanings"), &options);
+	QCheckBox sm(tr("Separate different meanings"), &options);
 	sm.setChecked(dictionary->separateMeanings);
 	sm.adjustSize();
 	sm.move(x, toek.y() + toek.height() + y);
 
-	QCheckBox lo(W2U("Output Bulgarian as latin"), &options);
+	QCheckBox lo(tr("Output Bulgarian as latin"), &options);
 	lo.setChecked(dictionary->latinOutput);
 	lo.adjustSize();
 	lo.move(x, sm.y() + sm.height() + y);
 
-	QCheckBox li(W2U("Input Bulgarian as BIG latin"), &options);
+	QCheckBox li(tr("Input Bulgarian as BIG latin"), &options);
 	li.setChecked(dictionary->latinInput);
 	li.adjustSize();
 	li.move(x, lo.y() + lo.height() + y);
 
-	QLabel lwil(W2U("Words in list:"), &options);
+	QLabel lwil(tr("Words in list:"), &options);
 	lwil.setAlignment(QLabel::AlignRight | QLabel::AlignVCenter);
 	lwil.adjustSize();
 	lwil.move(x, li.y() + li.height() + y + s);
@@ -751,7 +753,7 @@ void Win::menu_Options() {
 	wil.adjustSize();
 	wil.move(x + lwil.width() + w, lwil.y());
 
-	QLabel lwih(W2U("Words in history:"), &options);
+	QLabel lwih(tr("Words in history:"), &options);
 	lwih.setAlignment(QLabel::AlignRight | QLabel::AlignVCenter);
 	lwih.adjustSize();
 	lwih.move(x, wil.y() + wil.height() + y);
@@ -761,7 +763,7 @@ void Win::menu_Options() {
 	wih.adjustSize();
 	wih.move(x + lwih.width() + w, lwih.y());
 
-	QLabel llpw(W2U("Left pane width:"), &options);
+	QLabel llpw(tr("Left pane width:"), &options);
 	llpw.setAlignment(QLabel::AlignRight | QLabel::AlignVCenter);
 	llpw.adjustSize();
 	llpw.move(x, wih.y() + wih.height() + y);
@@ -771,7 +773,7 @@ void Win::menu_Options() {
 	lpw.adjustSize();
 	lpw.move(x + llpw.width() + w, llpw.y());
 
-	QLabel lifw(W2U("Input field width:"), &options);
+	QLabel lifw(tr("Input field width:"), &options);
 	lifw.setAlignment(QLabel::AlignRight | QLabel::AlignVCenter);
 	lifw.adjustSize();
 	lifw.move(x, lpw.y() + lpw.height() + y);
@@ -781,7 +783,7 @@ void Win::menu_Options() {
 	ifw.adjustSize();
 	ifw.move(x + lifw.width() + w, lifw.y());
 
-	QLabel lbw(W2U("Border width:"), &options);
+	QLabel lbw(tr("Border width:"), &options);
 	lbw.setAlignment(QLabel::AlignRight | QLabel::AlignVCenter);
 	lbw.adjustSize();
 	lbw.move(x, ifw.y() + ifw.height() + y);
@@ -816,32 +818,32 @@ void Win::menu_Options() {
 	ifw.move(x + m + w, ifw.y());
 	bw.move(x + m + w, bw.y());
 
-	QLabel alpw(W2U("pixels"), &options);
+	QLabel alpw(tr("pixels"), &options);
 	alpw.setAlignment(QLabel::AlignLeft | QLabel::AlignVCenter);
 	alpw.adjustSize();
 	alpw.setGeometry(lpw.x() + lpw.width() + w, lpw.y(), alpw.width(), lpw.height());
 
-	QLabel aifw(W2U("pixels"), &options);
+	QLabel aifw(tr("pixels"), &options);
 	aifw.setAlignment(QLabel::AlignLeft | QLabel::AlignVCenter);
 	aifw.adjustSize();
 	aifw.setGeometry(ifw.x() + ifw.width() + w, ifw.y(), aifw.width(), ifw.height());
 
-	QLabel abw(W2U("pixels"), &options);
+	QLabel abw(tr("pixels"), &options);
 	abw.setAlignment(QLabel::AlignLeft | QLabel::AlignVCenter);
 	abw.adjustSize();
 	abw.setGeometry(bw.x() + bw.width() + w, bw.y(), abw.width(), bw.height());
 
 #ifndef WITH_KDE
-	QLabel lss(W2U("Look&Feel style:"), &options);
+	QLabel lss(tr("Look and Feel:"), &options);
 	lss.setAlignment(QLabel::AlignLeft | QLabel::AlignVCenter);
 	lss.adjustSize();
 	lss.move(x, bw.y() + bw.height() + y + s);
 
 	QComboBox ss(false, &options);
-	ss.insertItem(W2U("Windows"));
-	ss.insertItem(W2U("CDE"));
-	ss.insertItem(W2U("Motif"));
-	ss.insertItem(W2U("Platinium"));
+	ss.insertItem(tr("Windows"));
+	ss.insertItem(tr("Motif Plus"));
+	ss.insertItem(tr("Motif"));
+	ss.insertItem(tr("Platinium"));
 	ss.setCurrentItem(systemStyle - 1);
 	ss.adjustSize();
 	ss.move(x + lss.width() + w, lss.y());
@@ -849,11 +851,11 @@ void Win::menu_Options() {
 	lss.resize(lss.width(), ss.height());
 #endif
 
-	QPushButton ok(W2U("OK"), &options);
+	QPushButton ok(tr("&OK"), &options);
 	ok.setDefault(true);
 	connect(&ok, SIGNAL(clicked()), &options, SLOT(accept()));
 
-	QPushButton cancel(W2U("Cancel"), &options);
+	QPushButton cancel(tr("&Cancel"), &options);
 	connect(&cancel, SIGNAL(clicked()), &options, SLOT(reject()));
 	cancel.adjustSize();
 
@@ -936,7 +938,7 @@ void Win::menu_Options() {
 void Win::menu_AdvancedSearch() {
 
 	QDialog options(this, "options", true);
-	options.setCaption(W2U("Advanced Search"));
+	options.setCaption(tr("Advanced Search"));
 
 	QFontMetrics fm = options.fontMetrics();
 	int h = fm.height();    // Height of element
@@ -945,51 +947,52 @@ void Win::menu_AdvancedSearch() {
 	int s = h;              // Additional space between groups
 	int m = 0;              // Max width of element (Used for alignment)
 
-	QCheckBox sww(W2U("Search for whole word(s)"), &options);
+	QCheckBox sww(tr("Search for whole word(s)"), &options);
 	sww.setChecked(dictionary->advancedSearchWholeWord);
 	sww.adjustSize();
 	sww.move(x, y);
 
-	QCheckBox sep(W2U("Search for exact phrase"), &options);
+	QCheckBox sep(tr("Search for exact phrase"), &options);
 	sep.setChecked(dictionary->advancedSearchExactPhrase);
 	sep.adjustSize();
 	sep.move(x, sww.y() + sww.height() + y);
 
-	QCheckBox chr(W2U("Color highlight result"), &options);
+	QCheckBox chr(tr("Color highlight result"), &options);
 	chr.setChecked(dictionary->advancedSearchHighlight);
 	chr.adjustSize();
 	chr.move(x, sep.y() + sep.height() + y);
 
-	QLabel lwasd(W2U("When advanced search syntax detected:"), &options);
+	QLabel lwasd(tr("When advanced search syntax detected:"), &options);
 	lwasd.setAlignment(QLabel::AlignRight | QLabel::AlignVCenter);
 	lwasd.adjustSize();
 	lwasd.move(x, chr.y() + chr.height() + y + s);
 
-	QCheckBox itoek(W2U("Ignore translate on every keystroke"), &options);
+	QCheckBox itoek(tr("Ignore translate on every keystroke"), &options);
 	itoek.setChecked(advSrchIgnoreKey);
 	itoek.adjustSize();
 	itoek.move(x, lwasd.y() + lwasd.height() + y);
 
-	QCheckBox iht(W2U("Ignore automatic translation from history"), &options);
+	QCheckBox iht(tr("Ignore automatic translation from history"), &options);
 	iht.setChecked(advSrchIgnoreHistory);
 	iht.adjustSize();
 	iht.move(x, itoek.y() + itoek.height() + y);
 
-	QCheckBox ewas(W2U("Enter perform advanced search"), &options);
-	ewas.setChecked(advSrchEnterSearch);
-	ewas.adjustSize();
-	ewas.move(x, iht.y() + iht.height() + y);
-
-	QCheckBox dnrp(W2U("Do not replace phrase in input field"), &options);
+	QCheckBox dnrp(tr("Do not replace phrase in input field"), &options);
 	dnrp.setChecked(advSrchDoNotReplacePhrase);
 	dnrp.adjustSize();
-	dnrp.move(x, ewas.y() + ewas.height() + y);
+	dnrp.move(x, iht.y() + iht.height() + y);
 
-	QPushButton ok(W2U("OK"), &options);
+	QCheckBox ewas(tr("Enter perform advanced search"), &options);
+	ewas.setChecked(advSrchEnterSearch);
+	ewas.adjustSize();
+	ewas.move(x, dnrp.y() + dnrp.height() + y);
+
+
+	QPushButton ok(tr("&OK"), &options);
 	ok.setDefault(true);
 	connect(&ok, SIGNAL(clicked()), &options, SLOT(accept()));
 
-	QPushButton cancel(W2U("Cancel"), &options);
+	QPushButton cancel(tr("&Cancel"), &options);
 	connect(&cancel, SIGNAL(clicked()), &options, SLOT(reject()));
 	cancel.adjustSize();
 
@@ -1004,10 +1007,10 @@ void Win::menu_AdvancedSearch() {
 	m = (ewas.width() > m ? ewas.width() : m);
 	m = (dnrp.width() > m ? dnrp.width() : m);
 
-	ok.setGeometry(m - cancel.width(), y, cancel.width(), cancel.height());
+	ok.setGeometry(m - cancel.width() + x, y, cancel.width(), cancel.height());
 	cancel.move(ok.x(), ok.y() + ok.height() + y);
 
-	options.setFixedSize(ok.x() + ok.width() + x, dnrp.y() + dnrp.height() + y);
+	options.setFixedSize(ok.x() + ok.width() + x, ewas.y() + ewas.height() + y);
 
 	// Execute dialog and check for OK button
 	if (options.exec() == QDialog::Accepted) {
@@ -1032,14 +1035,14 @@ void Win::menu_AdvancedSearch() {
 			advSrchIgnoreHistory = iht.isChecked();
 			reg->setBool(OPTION_ADV_SRCH_ASD_IGNORE_HIS, advSrchIgnoreHistory);
 		}
-		if (advSrchEnterSearch != ewas.isChecked()) {
-			advSrchEnterSearch = ewas.isChecked();
-			reg->setBool(OPTION_ADV_SRCH_ASD_ENTER, advSrchEnterSearch);
-		}
 		if (advSrchDoNotReplacePhrase != dnrp.isChecked()) {
 			advSrchDoNotReplacePhrase = dnrp.isChecked();
 			reg->setBool(OPTION_ADV_SRCH_ASD_DO_NOT_REPL, advSrchDoNotReplacePhrase);
 		}
+		if (advSrchEnterSearch != ewas.isChecked()) {
+			advSrchEnterSearch = ewas.isChecked();
+			reg->setBool(OPTION_ADV_SRCH_ASD_ENTER, advSrchEnterSearch);
+		}
 	}
 } // End of menu_AdvancedSearch
 
@@ -1053,9 +1056,7 @@ void Win::menu_Font() {
 	bool okSelected;
 	QFont f = QFont(font);
 #ifdef WITH_KDE
-	//okSelected = (KFontDialog::getFont(f, false, this) == QDialog::Accepted);
-	// To the moment KFontDialog doesn't provide way to select CharSet
-	f = QFontDialog::getFont(&okSelected, f, this);
+	okSelected = (KFontDialog::getFont(f, false, this) == QDialog::Accepted);
 #else
 	f = QFontDialog::getFont(&okSelected, f, this);
 #endif
@@ -1069,7 +1070,6 @@ void Win::menu_Font() {
 		reg->setInt(OPTION_FONT_SIZE, font.pointSize());
 		reg->setInt(OPTION_FONT_WEIGHT, font.weight());
 		reg->setBool(OPTION_FONT_ITALIC, font.italic());
-		reg->setInt(OPTION_FONT_CHARSET, font.charSet());
 		// Update view of main window
 		setView(0);
 		// Update word and translation
@@ -1085,7 +1085,7 @@ void Win::menu_Font() {
 //========================================================================
 void Win::menu_Test() {
 	Test t(this, "test", dictionary, reg, &font, borderWidth);
-	t.show();
+	t.exec();
 } // End of menu_Test
 
 
@@ -1094,7 +1094,9 @@ void Win::menu_Test() {
 // Show help message in translation result text area
 //========================================================================
 void Win::menu_Help() {
-	result->setText(W2U(HELP_MESSAGE));
+	result->setText(tr(HELP_MESSAGE));
+	result->sync();
+	result->setCursorPosition(0, 0);
 } // End of menu_Help
 
 
@@ -1106,7 +1108,7 @@ void Win::menu_About() {
 
 	// Define about dialog
 	QDialog about(this, "about", true);
-	about.setCaption(W2U("About"));
+	about.setCaption(tr("About"));
 
 	// Define space between elements
 	QFontMetrics fm = about.fontMetrics();
@@ -1116,18 +1118,18 @@ void Win::menu_About() {
 
 	// Define and set picture
 	QLabel picture(&about);
-	QPixmap picPixmap(dicicon);
+	QPixmap picPixmap(kbedic_icon);
 	picture.setPixmap(picPixmap);
 	picture.adjustSize();
 	picture.move(x, y);
 
 	// Define and set label
-	QLabel message(W2U(ABOUT_MESSAGE), &about);
+	QLabel message(tr(ABOUT_MESSAGE).arg(VERSION), &about);
 	message.adjustSize();
 	message.move(picture.x() + picture.width() + x, y);
-	
+
 	// Define and set OK button
-	QPushButton ok(W2U("OK"), &about);
+	QPushButton ok(tr("&Close"), &about);
 	ok.setDefault(true);
 	connect(&ok, SIGNAL(clicked()), &about, SLOT(accept()));
 	ok.adjustSize();
@@ -1151,16 +1153,16 @@ void Win::setView(int style) {
 #ifndef WITH_KDE
 	// Set Style View
 	if (style == 1) {
-		qApp->setStyle(new QWindowsStyle);
+		qApp->setStyle(new QWindowsStyle());
 	}
 	else if (style == 2) {
-		qApp->setStyle(new QCDEStyle);
+		qApp->setStyle(new QMotifPlusStyle());
 	}
 	else if (style == 3) {
-		qApp->setStyle(new QMotifStyle);
+		qApp->setStyle(new QMotifStyle());
 	}
 	else if (style == 4) {
-		qApp->setStyle(new QPlatinumStyle);
+		qApp->setStyle(new QPlatinumStyle());
 	}
 #endif
 
@@ -1188,8 +1190,8 @@ void Win::setView(int style) {
 	// Set label found
 	found->setFont(font);
 	int fl;
-	fl = (fm.width(W2U(FOUND)) > fm.width(W2U(NOT_FOUND)) ? fm.width(W2U(FOUND)) : fm.width(W2U(NOT_FOUND)));
-	fl = (fm.width(W2U(ADV_SRCH_LABEL)) > m ? fm.width(W2U(ADV_SRCH_LABEL)) : m);
+	fl = (fm.width(tr(FOUND)) > fm.width(tr(NOT_FOUND)) ? fm.width(tr(FOUND)) : fm.width(tr(NOT_FOUND)));
+	fl = (fm.width(tr(ADV_SRCH_LABEL).arg(MAX_WORDS_IN_LIST)) > m ? fm.width(tr(ADV_SRCH_LABEL).arg(MAX_WORDS_IN_LIST)) : m);
 	found->setGeometry(borderWidth + 1 + bnext->x() + bnext->width(), borderWidth + m, fl + 2, word->height());
 
 	// Set picture
@@ -1220,6 +1222,8 @@ void Win::setView(int style) {
 		result->setGeometry(borderWidth, borderWidth*2 + 1 + word->height() +  m, width() - borderWidth*2, height() - borderWidth*3 - word->height() - m - 1);
 	}
 	result->setText(result->text());
+	result->sync();
+	result->setCursorPosition(0, 0);
 
 } // End of setView
 
